summaryrefslogtreecommitdiffstats
path: root/system/renameutils/patches/typo_fix.patch
blob: 63e55f244eb075b397093c92a7e6427813f07115 (plain)
Description: Fix typo in error message
Forwarded: emailed
Author: Francois Marier <francois@debian.org>
Last-Update: 2018-05-10

--- a/po/fr.po
+++ b/po/fr.po
@@ -722,7 +722,7 @@ msgstr "Variable accessible en écriture seulement\n"
 #: src/common/error.c:104
 #, c-format
 msgid ""
-"An internal error has occured. Please report this error by sending the\n"
+"An internal error has occurred. Please report this error by sending the\n"
 "output below to %s.\n"
 "\n"
 "Program: %s\n"
diff --git a/po/renameutils.pot b/po/renameutils.pot
index 9c0c9c5..c3e3ea4 100644
--- a/po/renameutils.pot
+++ b/po/renameutils.pot
@@ -581,7 +581,7 @@ msgstr ""
 #: src/common/error.c:104
 #, c-format
 msgid ""
-"An internal error has occured. Please report this error by sending the\n"
+"An internal error has occurred. Please report this error by sending the\n"
 "output below to %s.\n"
 "\n"
 "Program: %s\n"
diff --git a/po/sv.po b/po/sv.po
index e44f1f8..784c410 100644
--- a/po/sv.po
+++ b/po/sv.po
@@ -705,7 +705,7 @@ msgstr "Skriv-enbart-variabel\n"
 #: src/common/error.c:104
 #, c-format
 msgid ""
-"An internal error has occured. Please report this error by sending the\n"
+"An internal error has occurred. Please report this error by sending the\n"
 "output below to %s.\n"
 "\n"
 "Program: %s\n"
diff --git a/src/common/error.c b/src/common/error.c
index 72ac9b5..d6544e3 100644
--- a/src/common/error.c
+++ b/src/common/error.c
@@ -87,7 +87,7 @@ free_error(void)
 
 /**
  * This function should be called when an internal error has
  * occured. It will display a more verbose message, asking
  * the user to mail the program author.
  *
  * @param msg
@@ -102,7 +102,7 @@ internal_error(const char *msg, ...)
 	if (program_termination_hook != NULL)
 		program_termination_hook();
 	fprintf(stderr, _("\
-An internal error has occured. Please report this error by sending the\n\
+An internal error has occurred. Please report this error by sending the\n\
 output below to %s.\n\
 \n\
 Program: %s\n\
@@ -87,7 +87,7 @@ free_error(void)
 /**
  * This function should be called when an internal error has
- * occured. It will display a more verbose message, asking
+ * occurred. It will display a more verbose message, asking
  * the user to mail the program author.
  *